"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .certificate_parsed import CertificateParsed, CertificateParsedTypedDict
from .certificaterevocation import CertificateRevocation, CertificateRevocationTypedDict
from .ct import Ct, CtTypedDict
from .validation import Validation, ValidationTypedDict
from .zlint import ZLint, ZLintTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ParseStatus(str, Enum):
    UNKNOWN = ""
    SUCCESS = "success"
    FAIL = "fail"
    CORRUPTED = "corrupted"


class ValidationLevel(str, Enum):
    r"""The extent to which the certificate's issuer validated the identity of the entity requesting the certificate. Options include Domain validated (DV), Organization Validated (OV), or Extended Validation (EV)."""

    UNKNOWN = ""
    DV = "dv"
    OV = "ov"
    EV = "ev"


class CertificateTypedDict(TypedDict):
    added_at: NotRequired[str]
    r"""When the certificate was added to the Censys dataset."""
    ct: NotRequired[CtTypedDict]
    ever_seen_in_scan: NotRequired[bool]
    r"""Whether the certificate has ever been presented by a service during a scan."""
    fingerprint_md5: NotRequired[str]
    r"""The MD-5 digest of the entire raw certificate. An identifier used by some systems."""
    fingerprint_sha1: NotRequired[str]
    r"""The SHA-1 digest of the entire raw certificate. An identifier used by some systems."""
    fingerprint_sha256: NotRequired[str]
    r"""The SHA-256 digest of the entire raw certificate. Its unique identifier, which Censys uses to index certificates records."""
    modified_at: NotRequired[str]
    r"""When the certificate record was last modified."""
    names: NotRequired[Nullable[List[str]]]
    r"""All the names contained in the certificate from various fields."""
    parent_spki_fingerprint_sha256: NotRequired[str]
    r"""DEPRECATED: Use parent_spki_subject_fingerprint_sha256"""
    parent_spki_subject_fingerprint_sha256: NotRequired[str]
    r"""The SHA-256 digest of the parent certificate's DER-encoded SubjectPublicKeyInfo concatenated with its Subject."""
    parse_status: NotRequired[ParseStatus]
    parsed: NotRequired[CertificateParsedTypedDict]
    precert: NotRequired[bool]
    r"""Whether the X.509 \"poison\" extension (OID: 1.3.6.1.4.1.11129.2.4.3) is marked critical, which prohibits the pre-certificate from being trusted."""
    revocation: NotRequired[CertificateRevocationTypedDict]
    revoked: NotRequired[bool]
    r"""Whether the certificate has been revoked before its expiry date by the issuer."""
    spki_fingerprint_sha256: NotRequired[str]
    r"""DEPRECATED: Use spki_subject_fingerprint_sha256"""
    spki_subject_fingerprint_sha256: NotRequired[str]
    r"""The SHA-256 digest of the certificate's DER-encoded SubjectPublicKeyInfo concatenated with its Subject."""
    tbs_fingerprint_sha256: NotRequired[str]
    r"""The SHA-256 digest of the unsigned certificate's contents."""
    tbs_no_ct_fingerprint_sha256: NotRequired[str]
    r"""The SHA-256 digest of the unsigned certificate with the CT Poison extension removed, if present. This represents the shared contents of a certificate and its corresponding pre-certificate."""
    validated_at: NotRequired[str]
    r"""When the certificate record's trust was last checked."""
    validation: NotRequired[ValidationTypedDict]
    validation_level: NotRequired[ValidationLevel]
    r"""The extent to which the certificate's issuer validated the identity of the entity requesting the certificate. Options include Domain validated (DV), Organization Validated (OV), or Extended Validation (EV)."""
    zlint: NotRequired[ZLintTypedDict]


class Certificate(BaseModel):
    added_at: Optional[str] = None
    r"""When the certificate was added to the Censys dataset."""

    ct: Optional[Ct] = None

    ever_seen_in_scan: Optional[bool] = None
    r"""Whether the certificate has ever been presented by a service during a scan."""

    fingerprint_md5: Optional[str] = None
    r"""The MD-5 digest of the entire raw certificate. An identifier used by some systems."""

    fingerprint_sha1: Optional[str] = None
    r"""The SHA-1 digest of the entire raw certificate. An identifier used by some systems."""

    fingerprint_sha256: Optional[str] = None
    r"""The SHA-256 digest of the entire raw certificate. Its unique identifier, which Censys uses to index certificates records."""

    modified_at: Optional[str] = None
    r"""When the certificate record was last modified."""

    names: OptionalNullable[List[str]] = UNSET
    r"""All the names contained in the certificate from various fields."""

    parent_spki_fingerprint_sha256: Optional[str] = None
    r"""DEPRECATED: Use parent_spki_subject_fingerprint_sha256"""

    parent_spki_subject_fingerprint_sha256: Optional[str] = None
    r"""The SHA-256 digest of the parent certificate's DER-encoded SubjectPublicKeyInfo concatenated with its Subject."""

    parse_status: Optional[ParseStatus] = None

    parsed: Optional[CertificateParsed] = None

    precert: Optional[bool] = None
    r"""Whether the X.509 \"poison\" extension (OID: 1.3.6.1.4.1.11129.2.4.3) is marked critical, which prohibits the pre-certificate from being trusted."""

    revocation: Optional[CertificateRevocation] = None

    revoked: Optional[bool] = None
    r"""Whether the certificate has been revoked before its expiry date by the issuer."""

    spki_fingerprint_sha256: Optional[str] = None
    r"""DEPRECATED: Use spki_subject_fingerprint_sha256"""

    spki_subject_fingerprint_sha256: Optional[str] = None
    r"""The SHA-256 digest of the certificate's DER-encoded SubjectPublicKeyInfo concatenated with its Subject."""

    tbs_fingerprint_sha256: Optional[str] = None
    r"""The SHA-256 digest of the unsigned certificate's contents."""

    tbs_no_ct_fingerprint_sha256: Optional[str] = None
    r"""The SHA-256 digest of the unsigned certificate with the CT Poison extension removed, if present. This represents the shared contents of a certificate and its corresponding pre-certificate."""

    validated_at: Optional[str] = None
    r"""When the certificate record's trust was last checked."""

    validation: Optional[Validation] = None

    validation_level: Optional[ValidationLevel] = None
    r"""The extent to which the certificate's issuer validated the identity of the entity requesting the certificate. Options include Domain validated (DV), Organization Validated (OV), or Extended Validation (EV)."""

    zlint: Optional[ZLint] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "added_at",
            "ct",
            "ever_seen_in_scan",
            "fingerprint_md5",
            "fingerprint_sha1",
            "fingerprint_sha256",
            "modified_at",
            "names",
            "parent_spki_fingerprint_sha256",
            "parent_spki_subject_fingerprint_sha256",
            "parse_status",
            "parsed",
            "precert",
            "revocation",
            "revoked",
            "spki_fingerprint_sha256",
            "spki_subject_fingerprint_sha256",
            "tbs_fingerprint_sha256",
            "tbs_no_ct_fingerprint_sha256",
            "validated_at",
            "validation",
            "validation_level",
            "zlint",
        ]
        nullable_fields = ["names"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SearchCapabilitiesTypedDict(TypedDict):
    general_start_events: NotRequired[bool]
    metadata_search: NotRequired[bool]


class SearchCapabilities(BaseModel):
    general_start_events: Optional[bool] = None

    metadata_search: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiCapabilitiesSupportedAuthTypesTypedDict(TypedDict):
    extended: NotRequired[bool]
    r"""If true, the extended capabilities are present."""
    md2: NotRequired[bool]
    r"""True if the MD2 AuthType is supported."""
    md5: NotRequired[bool]
    r"""True if the MD5 AuthType is supported."""
    none: NotRequired[bool]
    r"""True if the None AuthType is supported."""
    oem_proprietary: NotRequired[bool]
    r"""True if the OEM Proprietary AuthType is supported"""
    password: NotRequired[bool]
    r"""True if the Password AuthType is supported."""
    raw: NotRequired[int]
    r"""The raw byte, with the bit mask etc"""


class IpmiCapabilitiesSupportedAuthTypes(BaseModel):
    extended: Optional[bool] = None
    r"""If true, the extended capabilities are present."""

    md2: Optional[bool] = None
    r"""True if the MD2 AuthType is supported."""

    md5: Optional[bool] = None
    r"""True if the MD5 AuthType is supported."""

    none: Optional[bool] = None
    r"""True if the None AuthType is supported."""

    oem_proprietary: Optional[bool] = None
    r"""True if the OEM Proprietary AuthType is supported"""

    password: Optional[bool] = None
    r"""True if the Password AuthType is supported."""

    raw: Optional[int] = None
    r"""The raw byte, with the bit mask etc"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class BacnetTypedDict(TypedDict):
    application_software_revision: NotRequired[str]
    description: NotRequired[str]
    firmware_revision: NotRequired[str]
    instance_number: NotRequired[int]
    location: NotRequired[str]
    model_name: NotRequired[str]
    object_name: NotRequired[str]
    vendor_id: NotRequired[int]
    vendor_name: NotRequired[str]


class Bacnet(BaseModel):
    application_software_revision: Optional[str] = None

    description: Optional[str] = None

    firmware_revision: Optional[str] = None

    instance_number: Optional[int] = None

    location: Optional[str] = None

    model_name: Optional[str] = None

    object_name: Optional[str] = None

    vendor_id: Optional[int] = None

    vendor_name: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EipServiceTypedDict(TypedDict):
    capabilities: NotRequired[int]
    service_name: NotRequired[str]
    supports_tcp: NotRequired[bool]
    supports_udp: NotRequired[bool]


class EipService(BaseModel):
    capabilities: Optional[int] = None

    service_name: Optional[str] = None

    supports_tcp: Optional[bool] = None

    supports_udp: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Version(str, Enum):
    UNKNOWN = ""
    SS_LV_2 = "ss_lv_2"
    SS_LV_3 = "ss_lv_3"
    TLSV1_0 = "tlsv1_0"
    TLSV1_1 = "tlsv1_1"
    TLSV1_2 = "tlsv1_2"
    TLSV1_3 = "tlsv1_3"
    DTLSV1_0 = "dtlsv1_0"
    DTLSV1_2 = "dtlsv1_2"
    DTLSV1_3 = "dtlsv1_3"


class TLSVersionDataTypedDict(TypedDict):
    ja3s: NotRequired[str]
    ja4s: NotRequired[str]
    version: NotRequired[Version]


class TLSVersionData(BaseModel):
    ja3s: Optional[str] = None

    ja4s: Optional[str] = None

    version: Optional[Version] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TplinkKasaTypedDict(TypedDict):
    active_mode: NotRequired[str]
    brightness: NotRequired[int]
    dev_name: NotRequired[str]
    err_code: NotRequired[int]
    feature: NotRequired[str]
    hw_ver: NotRequired[str]
    icon_hash: NotRequired[str]
    led_off: NotRequired[int]
    mic_type: NotRequired[str]
    model: NotRequired[str]
    on_time: NotRequired[int]
    relay_state: NotRequired[int]
    rssi: NotRequired[int]
    sw_ver: NotRequired[str]
    updating: NotRequired[int]


class TplinkKasa(BaseModel):
    active_mode: Optional[str] = None

    brightness: Optional[int] = None

    dev_name: Optional[str] = None

    err_code: Optional[int] = None

    feature: Optional[str] = None

    hw_ver: Optional[str] = None

    icon_hash: Optional[str] = None

    led_off: Optional[int] = None

    mic_type: Optional[str] = None

    model: Optional[str] = None

    on_time: Optional[int] = None

    relay_state: Optional[int] = None

    rssi: Optional[int] = None

    sw_ver: Optional[str] = None

    updating: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class NetworkCapabilitiesTypedDict(TypedDict):
    dhcp_v6: NotRequired[bool]
    dot11_configuration: NotRequired[bool]
    dot1x_configurations: NotRequired[int]
    dynamic_dns: NotRequired[bool]
    hostname_from_dhcp: NotRequired[bool]
    ip_filter: NotRequired[bool]
    ipv6: NotRequired[bool]
    ntp: NotRequired[int]
    zero_configuration: NotRequired[bool]


class NetworkCapabilities(BaseModel):
    dhcp_v6: Optional[bool] = None

    dot11_configuration: Optional[bool] = None

    dot1x_configurations: Optional[int] = None

    dynamic_dns: Optional[bool] = None

    hostname_from_dhcp: Optional[bool] = None

    ip_filter: Optional[bool] = None

    ipv6: Optional[bool] = None

    ntp: Optional[int] = None

    zero_configuration: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .prometheus_response_activetarget import (
    PrometheusResponseActiveTarget,
    PrometheusResponseActiveTargetTypedDict,
)
from .prometheus_response_droppedtarget import (
    PrometheusResponseDroppedTarget,
    PrometheusResponseDroppedTargetTypedDict,
)
from .prometheus_response_prometheusversion import (
    PrometheusResponsePrometheusVersion,
    PrometheusResponsePrometheusVersionTypedDict,
)
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class PrometheusResponseTypedDict(TypedDict):
    active_targets: NotRequired[Nullable[List[PrometheusResponseActiveTargetTypedDict]]]
    r"""List of active targets."""
    all_versions: NotRequired[Nullable[List[str]]]
    r"""List of the versions of everything that Prometheus finds i.e., version of Prometheus, Go, Node, cAdvisor, etc."""
    config_exposed: NotRequired[bool]
    r"""True when the config endpoint is exposed."""
    dropped_targets: NotRequired[
        Nullable[List[PrometheusResponseDroppedTargetTypedDict]]
    ]
    r"""List of dropped targets."""
    go_versions: NotRequired[Nullable[List[str]]]
    r"""List of the versions of Go."""
    prometheus_versions: NotRequired[
        Nullable[List[PrometheusResponsePrometheusVersionTypedDict]]
    ]


class PrometheusResponse(BaseModel):
    active_targets: OptionalNullable[List[PrometheusResponseActiveTarget]] = UNSET
    r"""List of active targets."""

    all_versions: OptionalNullable[List[str]] = UNSET
    r"""List of the versions of everything that Prometheus finds i.e., version of Prometheus, Go, Node, cAdvisor, etc."""

    config_exposed: Optional[bool] = None
    r"""True when the config endpoint is exposed."""

    dropped_targets: OptionalNullable[List[PrometheusResponseDroppedTarget]] = UNSET
    r"""List of dropped targets."""

    go_versions: OptionalNullable[List[str]] = UNSET
    r"""List of the versions of Go."""

    prometheus_versions: OptionalNullable[List[PrometheusResponsePrometheusVersion]] = (
        UNSET
    )

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "active_targets",
            "all_versions",
            "config_exposed",
            "dropped_targets",
            "go_versions",
            "prometheus_versions",
        ]
        nullable_fields = [
            "active_targets",
            "all_versions",
            "dropped_targets",
            "go_versions",
            "prometheus_versions",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing_extensions import TypedDict


class ConvertQueryErrorTypedDict(TypedDict):
    message: str
    r"""The error message if the query could not be converted."""


class ConvertQueryError(BaseModel):
    message: str
    r"""The error message if the query could not be converted."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ProfinetCmTypedDict(TypedDict):
    byte_order: NotRequired[str]
    lookup_response_raw: NotRequired[str]
    multiple_fragments: NotRequired[bool]


class ProfinetCm(BaseModel):
    byte_order: Optional[str] = None

    lookup_response_raw: Optional[str] = None

    multiple_fragments: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .attribute import Attribute, AttributeTypedDict
from .hostdns import HostDNS, HostDNSTypedDict
from .label import Label, LabelTypedDict
from .location import Location, LocationTypedDict
from .routing import Routing, RoutingTypedDict
from .service import Service, ServiceTypedDict
from .whois import Whois, WhoisTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class HostTypedDict(TypedDict):
    autonomous_system: NotRequired[RoutingTypedDict]
    dns: NotRequired[HostDNSTypedDict]
    hardware: NotRequired[AttributeTypedDict]
    ip: NotRequired[str]
    labels: NotRequired[Nullable[List[LabelTypedDict]]]
    location: NotRequired[LocationTypedDict]
    operating_system: NotRequired[AttributeTypedDict]
    service_count: NotRequired[int]
    services: NotRequired[Nullable[List[ServiceTypedDict]]]
    whois: NotRequired[WhoisTypedDict]


class Host(BaseModel):
    autonomous_system: Optional[Routing] = None

    dns: Optional[HostDNS] = None

    hardware: Optional[Attribute] = None

    ip: Optional[str] = None

    labels: OptionalNullable[List[Label]] = UNSET

    location: Optional[Location] = None

    operating_system: Optional[Attribute] = None

    service_count: Optional[int] = None

    services: OptionalNullable[List[Service]] = UNSET

    whois: Optional[Whois] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "autonomous_system",
            "dns",
            "hardware",
            "ip",
            "labels",
            "location",
            "operating_system",
            "service_count",
            "services",
            "whois",
        ]
        nullable_fields = ["labels", "services"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .eventassetchange import EventAssetChange, EventAssetChangeTypedDict
from .eventstatuschange import EventStatusChange, EventStatusChangeTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CollectionEventTypedDict(TypedDict):
    asset_change: NotRequired[EventAssetChangeTypedDict]
    status_change: NotRequired[EventStatusChangeTypedDict]


class CollectionEvent(BaseModel):
    asset_change: Optional[EventAssetChange] = None

    status_change: Optional[EventStatusChange] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class NodeInfoV2TypedDict(TypedDict):
    decimals: NotRequired[int]
    features: NotRequired[Nullable[List[str]]]
    is_healthy: NotRequired[bool]
    latest_milestone: NotRequired[int]
    latest_uncommitted_milestone: NotRequired[int]
    name: NotRequired[str]
    network_name: NotRequired[str]
    protocol_version: NotRequired[int]
    subunit: NotRequired[str]
    supported_protocol_versions: NotRequired[Nullable[List[int]]]
    ticker_symbol: NotRequired[str]
    token_name: NotRequired[str]
    token_supply: NotRequired[str]
    unit: NotRequired[str]
    version: NotRequired[str]


class NodeInfoV2(BaseModel):
    decimals: Optional[int] = None

    features: OptionalNullable[List[str]] = UNSET

    is_healthy: Optional[bool] = None

    latest_milestone: Optional[int] = None

    latest_uncommitted_milestone: Optional[int] = None

    name: Optional[str] = None

    network_name: Optional[str] = None

    protocol_version: Optional[int] = None

    subunit: Optional[str] = None

    supported_protocol_versions: OptionalNullable[List[int]] = UNSET

    ticker_symbol: Optional[str] = None

    token_name: Optional[str] = None

    token_supply: Optional[str] = None

    unit: Optional[str] = None

    version: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "decimals",
            "features",
            "is_healthy",
            "latest_milestone",
            "latest_uncommitted_milestone",
            "name",
            "network_name",
            "protocol_version",
            "subunit",
            "supported_protocol_versions",
            "ticker_symbol",
            "token_name",
            "token_supply",
            "unit",
            "version",
        ]
        nullable_fields = ["features", "supported_protocol_versions"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .smb_headerlog import SmbHeaderLog, SmbHeaderLogTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SmbSessionSetupLogTypedDict(TypedDict):
    header_log: NotRequired[SmbHeaderLogTypedDict]
    negotiate_flags: NotRequired[int]
    setup_flags: NotRequired[int]
    target_name: NotRequired[str]


class SmbSessionSetupLog(BaseModel):
    header_log: Optional[SmbHeaderLog] = None

    negotiate_flags: Optional[int] = None

    setup_flags: Optional[int] = None

    target_name: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rootstore_chain import RootStoreChain, RootStoreChainTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class Type(str, Enum):
    r"""The certificate's type. Options include root, intermediate, or leaf."""

    UNKNOWN = ""
    ROOT = "root"
    INTERMEDIATE = "intermediate"
    LEAF = "leaf"


class RootStoreTypedDict(TypedDict):
    chains: NotRequired[Nullable[List[RootStoreChainTypedDict]]]
    r"""A path of trusted signing certificates up to a root certificate present in a root store, represented as an ordered list of SHA-256 fingerprints."""
    ever_valid: NotRequired[bool]
    r"""Whether the certificate has ever been considered valid by the root store."""
    had_trusted_path: NotRequired[bool]
    r"""Whether there ever existed a trusted path of signing certificates from a certificate present in the root certificate store."""
    has_trusted_path: NotRequired[bool]
    r"""Whether there currently exists a trusted path of signing certificates from a certificate present in the root certificate store."""
    in_revocation_set: NotRequired[bool]
    r"""Whether the certificate is in the revocation set (e.g. OneCRL) associated with the root store."""
    is_valid: NotRequired[bool]
    r"""Whether the certificate is currently considered valid by the root store: a summary of the trust path, revoked, blocklisted/allowlisted, and expired fields."""
    parents: NotRequired[Nullable[List[str]]]
    r"""The SHA-256 fingerprints of the certificate's immediate parents in its trust path(s)."""
    type: NotRequired[Type]
    r"""The certificate's type. Options include root, intermediate, or leaf."""


class RootStore(BaseModel):
    chains: OptionalNullable[List[RootStoreChain]] = UNSET
    r"""A path of trusted signing certificates up to a root certificate present in a root store, represented as an ordered list of SHA-256 fingerprints."""

    ever_valid: Optional[bool] = None
    r"""Whether the certificate has ever been considered valid by the root store."""

    had_trusted_path: Optional[bool] = None
    r"""Whether there ever existed a trusted path of signing certificates from a certificate present in the root certificate store."""

    has_trusted_path: Optional[bool] = None
    r"""Whether there currently exists a trusted path of signing certificates from a certificate present in the root certificate store."""

    in_revocation_set: Optional[bool] = None
    r"""Whether the certificate is in the revocation set (e.g. OneCRL) associated with the root store."""

    is_valid: Optional[bool] = None
    r"""Whether the certificate is currently considered valid by the root store: a summary of the trust path, revoked, blocklisted/allowlisted, and expired fields."""

    parents: OptionalNullable[List[str]] = UNSET
    r"""The SHA-256 fingerprints of the certificate's immediate parents in its trust path(s)."""

    type: Optional[Type] = None
    r"""The certificate's type. Options include root, intermediate, or leaf."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "chains",
            "ever_valid",
            "had_trusted_path",
            "has_trusted_path",
            "in_revocation_set",
            "is_valid",
            "parents",
            "type",
        ]
        nullable_fields = ["chains", "parents"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FieldDiffTypedDict(TypedDict):
    new: NotRequired[str]
    old: NotRequired[str]


class FieldDiff(BaseModel):
    new: Optional[str] = None

    old: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DeviceIOCapabilitiesTypedDict(TypedDict):
    audio_outputs: NotRequired[int]
    audio_sources: NotRequired[int]
    digital_inputs: NotRequired[int]
    relay_outputs: NotRequired[int]
    serial_ports: NotRequired[int]
    video_outputs: NotRequired[int]
    video_source: NotRequired[int]


class DeviceIOCapabilities(BaseModel):
    audio_outputs: Optional[int] = None

    audio_sources: Optional[int] = None

    digital_inputs: Optional[int] = None

    relay_outputs: Optional[int] = None

    serial_ports: Optional[int] = None

    video_outputs: Optional[int] = None

    video_source: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RippleClioResultsTypedDict(TypedDict):
    clio_version: NotRequired[str]
    rippled_version: NotRequired[str]
    validated: NotRequired[bool]
    validation_quorum: NotRequired[int]


class RippleClioResults(BaseModel):
    clio_version: Optional[str] = None

    rippled_version: Optional[str] = None

    validated: Optional[bool] = None

    validation_quorum: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpProtocolFlagsTypedDict(TypedDict):
    dynvc_graphics_pipeline: NotRequired[bool]
    extended_client_data_supported: NotRequired[bool]
    neg_resp_reserved: NotRequired[bool]
    restricted_admin_mode: NotRequired[bool]
    restricted_auth_mode: NotRequired[bool]


class RdpProtocolFlags(BaseModel):
    dynvc_graphics_pipeline: Optional[bool] = None

    extended_client_data_supported: Optional[bool] = None

    neg_resp_reserved: Optional[bool] = None

    restricted_admin_mode: Optional[bool] = None

    restricted_auth_mode: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UnitronicsPcomTypedDict(TypedDict):
    buffer_size: NotRequired[str]
    hardware_version: NotRequired[str]
    model: NotRequired[str]
    model_executor: NotRequired[str]
    model_op_executor: NotRequired[str]
    name: NotRequired[str]
    os_build: NotRequired[str]
    os_version: NotRequired[str]
    unique_id: NotRequired[int]
    unit_id: NotRequired[str]


class UnitronicsPcom(BaseModel):
    buffer_size: Optional[str] = None

    hardware_version: Optional[str] = None

    model: Optional[str] = None

    model_executor: Optional[str] = None

    model_op_executor: Optional[str] = None

    name: Optional[str] = None

    os_build: Optional[str] = None

    os_version: Optional[str] = None

    unique_id: Optional[int] = None

    unit_id: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ReplayCapabilitiesTypedDict(TypedDict):
    reverse_playback: NotRequired[bool]
    rtp_rtsp_tcp: NotRequired[bool]
    session_timeout_range: NotRequired[str]


class ReplayCapabilities(BaseModel):
    reverse_playback: Optional[bool] = None

    rtp_rtsp_tcp: Optional[bool] = None

    session_timeout_range: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ciscoipsla_handshake_header import (
    CiscoIpslaHandshakeHeader,
    CiscoIpslaHandshakeHeaderTypedDict,
)
from .ciscoipsla_handshake_message import (
    CiscoIpslaHandshakeMessage,
    CiscoIpslaHandshakeMessageTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CiscoIpslaHandshakeTypedDict(TypedDict):
    header: NotRequired[CiscoIpslaHandshakeHeaderTypedDict]
    message: NotRequired[CiscoIpslaHandshakeMessageTypedDict]


class CiscoIpslaHandshake(BaseModel):
    header: Optional[CiscoIpslaHandshakeHeader] = None

    message: Optional[CiscoIpslaHandshakeMessage] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataThreadPoolTypedDict(TypedDict):
    keep_alive: NotRequired[str]
    max: NotRequired[int]
    min: NotRequired[int]
    queue_size: NotRequired[int]
    type: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeDataThreadPool(BaseModel):
    keep_alive: Optional[str] = None

    max: Optional[int] = None

    min: Optional[int] = None

    queue_size: Optional[int] = None

    type: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KubernetesEndpointSubsetPortTypedDict(TypedDict):
    name: NotRequired[str]
    port: NotRequired[int]
    protocol: NotRequired[str]


class KubernetesEndpointSubsetPort(BaseModel):
    name: Optional[str] = None

    port: Optional[int] = None

    protocol: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KeyAlgorithmTypedDict(TypedDict):
    name: NotRequired[str]
    r"""Name of public key type, such as RSA or ECDSA. Information specific to the key type is available in the named sub-record."""
    oid: NotRequired[str]


class KeyAlgorithm(BaseModel):
    name: Optional[str] = None
    r"""Name of public key type, such as RSA or ECDSA. Information specific to the key type is available in the named sub-record."""

    oid: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OpcUaUserTokenPolicyTypedDict(TypedDict):
    issued_token_type: NotRequired[str]
    issuer_endpoint_url: NotRequired[str]
    policy_id: NotRequired[str]
    security_policy_uri: NotRequired[str]
    token_type: NotRequired[int]


class OpcUaUserTokenPolicy(BaseModel):
    issued_token_type: Optional[str] = None

    issuer_endpoint_url: Optional[str] = None

    policy_id: Optional[str] = None

    security_policy_uri: Optional[str] = None

    token_type: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .desktopinfo import DesktopInfo, DesktopInfoTypedDict
from .vnc_keyvalue import VncKeyValue, VncKeyValueTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class VncTypedDict(TypedDict):
    connection_failed_reason: NotRequired[str]
    r"""If server terminates handshake, the reason offered (if any)"""
    desktop_name: NotRequired[str]
    r"""Desktop name provided by the server, capped at 255 bytes"""
    pixel_encoding: NotRequired[VncKeyValueTypedDict]
    screen_info: NotRequired[DesktopInfoTypedDict]
    security_types: NotRequired[Nullable[List[VncKeyValueTypedDict]]]
    r"""server-specified security options"""
    version: NotRequired[str]


class Vnc(BaseModel):
    connection_failed_reason: Optional[str] = None
    r"""If server terminates handshake, the reason offered (if any)"""

    desktop_name: Optional[str] = None
    r"""Desktop name provided by the server, capped at 255 bytes"""

    pixel_encoding: Optional[VncKeyValue] = None

    screen_info: Optional[DesktopInfo] = None

    security_types: OptionalNullable[List[VncKeyValue]] = UNSET
    r"""server-specified security options"""

    version: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "connection_failed_reason",
            "desktop_name",
            "pixel_encoding",
            "screen_info",
            "security_types",
            "version",
        ]
        nullable_fields = ["security_types"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SignedCertificateTimestampSignatureTypedDict(TypedDict):
    hash_algorithm: NotRequired[str]
    signature: NotRequired[str]
    signature_algorithm: NotRequired[str]


class SignedCertificateTimestampSignature(BaseModel):
    hash_algorithm: Optional[str] = None

    signature: Optional[str] = None

    signature_algorithm: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ForwardDNSResolvedTypedDict(TypedDict):
    name: NotRequired[str]
    resolve_time: NotRequired[str]


class ForwardDNSResolved(BaseModel):
    name: Optional[str] = None

    resolve_time: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .etcd_v2 import EtcdV2, EtcdV2TypedDict
from .etcd_v3 import EtcdV3, EtcdV3TypedDict
from .etcd_version import EtcdVersion, EtcdVersionTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EtcdTypedDict(TypedDict):
    v2: NotRequired[EtcdV2TypedDict]
    v3: NotRequired[EtcdV3TypedDict]
    version: NotRequired[EtcdVersionTypedDict]


class Etcd(BaseModel):
    v2: Optional[EtcdV2] = None

    v3: Optional[EtcdV3] = None

    version: Optional[EtcdVersion] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_nodes_nodedata_nodesettings_node_attr_ml import (
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrML,
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrMLTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrTypedDict(TypedDict):
    ml: NotRequired[
        ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrMLTypedDict
    ]
    xpack_installed: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttr(BaseModel):
    ml: Optional[ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrML] = None

    xpack_installed: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KeyUsageTypedDict(TypedDict):
    certificate_sign: NotRequired[bool]
    r"""Whether the keyCertSign bit is set."""
    content_commitment: NotRequired[bool]
    r"""Whether the contentCommitment (formerly called nonRepudiation) bit is set."""
    crl_sign: NotRequired[bool]
    r"""Whether the cRLSign bit is set."""
    data_encipherment: NotRequired[bool]
    r"""Whether the dataEncipherment bit is set."""
    decipher_only: NotRequired[bool]
    r"""Whether the decipherOnly bit is set."""
    digital_signature: NotRequired[bool]
    r"""Whether the digitalSignature bit is set."""
    encipher_only: NotRequired[bool]
    r"""Whether the encipherOnly bit is set."""
    key_agreement: NotRequired[bool]
    r"""Whether the keyAgreement bit is set."""
    key_encipherment: NotRequired[bool]
    r"""Whether the keyEncipherment bit is set."""
    value: NotRequired[int]
    r"""The integer value of the bitmask in the extension."""


class KeyUsage(BaseModel):
    certificate_sign: Optional[bool] = None
    r"""Whether the keyCertSign bit is set."""

    content_commitment: Optional[bool] = None
    r"""Whether the contentCommitment (formerly called nonRepudiation) bit is set."""

    crl_sign: Optional[bool] = None
    r"""Whether the cRLSign bit is set."""

    data_encipherment: Optional[bool] = None
    r"""Whether the dataEncipherment bit is set."""

    decipher_only: Optional[bool] = None
    r"""Whether the decipherOnly bit is set."""

    digital_signature: Optional[bool] = None
    r"""Whether the digitalSignature bit is set."""

    encipher_only: Optional[bool] = None
    r"""Whether the encipherOnly bit is set."""

    key_agreement: Optional[bool] = None
    r"""Whether the keyAgreement bit is set."""

    key_encipherment: Optional[bool] = None
    r"""Whether the keyEncipherment bit is set."""

    value: Optional[int] = None
    r"""The integer value of the bitmask in the extension."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class DistinguishedNameTypedDict(TypedDict):
    common_name: NotRequired[Nullable[List[str]]]
    r"""The commonName (CN) elements of the Distinguished Name (OID: 2.5.4.3)."""
    country: NotRequired[Nullable[List[str]]]
    r"""The countryName (C) elements of the Distinguished Name (OID: 2.5.4.6)."""
    domain_component: NotRequired[Nullable[List[str]]]
    r"""The domainComponent (DC) elements of the Distinguished Name (OID: 0.9.2342.19200300.100.1.25)."""
    email_address: NotRequired[Nullable[List[str]]]
    r"""The emailAddress (E) elements of the Distinguished Name (OID: 1.2.840.113549.1.9.1)."""
    given_name: NotRequired[Nullable[List[str]]]
    r"""The givenName (G) elements of the Distinguished Name (OID: 2.5.4.42)."""
    jurisdiction_country: NotRequired[Nullable[List[str]]]
    r"""The jurisdictionCountry elements of the Distinguished Name (OID: 1.3.6.1.4.1.311.60.2.1.3)."""
    jurisdiction_locality: NotRequired[Nullable[List[str]]]
    r"""The jurisdictionLocality elements of the Distinguished Name (OID: 1.3.6.1.4.1.311.60.2.1.1)."""
    jurisdiction_province: NotRequired[Nullable[List[str]]]
    r"""The jurisdictionStateOrProvince elements of the Distinguished Name (OID: 1.3.6.1.4.1.311.60.2.1.2)."""
    locality: NotRequired[Nullable[List[str]]]
    r"""The localityName (L) elements of the Distinguished Name (OID: 2.5.4.7)."""
    organization: NotRequired[Nullable[List[str]]]
    r"""The organizationName (O) elements of the Distinguished Name (OID: 2.5.4.10)."""
    organization_id: NotRequired[Nullable[List[str]]]
    organizational_unit: NotRequired[Nullable[List[str]]]
    r"""The organizationalUnit (OU) elements of the Distinguished Name (OID: 2.5.4.11)."""
    postal_code: NotRequired[Nullable[List[str]]]
    r"""The postalCode elements of the Distinguished Name (OID: 2.5.4.17)."""
    province: NotRequired[Nullable[List[str]]]
    r"""The stateOrProvinceName (ST) elements of the Distinguished Name (OID: 2.5.4.8)."""
    serial_number: NotRequired[Nullable[List[str]]]
    r"""The serialNumber elements of the Distinguished Name (OID: 2.5.4.5)."""
    street_address: NotRequired[Nullable[List[str]]]
    r"""The streetAddress (STREET) elements of the Distinguished Name (OID: 2.5.4.9)."""
    surname: NotRequired[Nullable[List[str]]]
    r"""The surname (SN) elements of the Distinguished Name (OID: 2.5.4.4)."""


class DistinguishedName(BaseModel):
    common_name: OptionalNullable[List[str]] = UNSET
    r"""The commonName (CN) elements of the Distinguished Name (OID: 2.5.4.3)."""

    country: OptionalNullable[List[str]] = UNSET
    r"""The countryName (C) elements of the Distinguished Name (OID: 2.5.4.6)."""

    domain_component: OptionalNullable[List[str]] = UNSET
    r"""The domainComponent (DC) elements of the Distinguished Name (OID: 0.9.2342.19200300.100.1.25)."""

    email_address: OptionalNullable[List[str]] = UNSET
    r"""The emailAddress (E) elements of the Distinguished Name (OID: 1.2.840.113549.1.9.1)."""

    given_name: OptionalNullable[List[str]] = UNSET
    r"""The givenName (G) elements of the Distinguished Name (OID: 2.5.4.42)."""

    jurisdiction_country: OptionalNullable[List[str]] = UNSET
    r"""The jurisdictionCountry elements of the Distinguished Name (OID: 1.3.6.1.4.1.311.60.2.1.3)."""

    jurisdiction_locality: OptionalNullable[List[str]] = UNSET
    r"""The jurisdictionLocality elements of the Distinguished Name (OID: 1.3.6.1.4.1.311.60.2.1.1)."""

    jurisdiction_province: OptionalNullable[List[str]] = UNSET
    r"""The jurisdictionStateOrProvince elements of the Distinguished Name (OID: 1.3.6.1.4.1.311.60.2.1.2)."""

    locality: OptionalNullable[List[str]] = UNSET
    r"""The localityName (L) elements of the Distinguished Name (OID: 2.5.4.7)."""

    organization: OptionalNullable[List[str]] = UNSET
    r"""The organizationName (O) elements of the Distinguished Name (OID: 2.5.4.10)."""

    organization_id: OptionalNullable[List[str]] = UNSET

    organizational_unit: OptionalNullable[List[str]] = UNSET
    r"""The organizationalUnit (OU) elements of the Distinguished Name (OID: 2.5.4.11)."""

    postal_code: OptionalNullable[List[str]] = UNSET
    r"""The postalCode elements of the Distinguished Name (OID: 2.5.4.17)."""

    province: OptionalNullable[List[str]] = UNSET
    r"""The stateOrProvinceName (ST) elements of the Distinguished Name (OID: 2.5.4.8)."""

    serial_number: OptionalNullable[List[str]] = UNSET
    r"""The serialNumber elements of the Distinguished Name (OID: 2.5.4.5)."""

    street_address: OptionalNullable[List[str]] = UNSET
    r"""The streetAddress (STREET) elements of the Distinguished Name (OID: 2.5.4.9)."""

    surname: OptionalNullable[List[str]] = UNSET
    r"""The surname (SN) elements of the Distinguished Name (OID: 2.5.4.4)."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "common_name",
            "country",
            "domain_component",
            "email_address",
            "given_name",
            "jurisdiction_country",
            "jurisdiction_locality",
            "jurisdiction_province",
            "locality",
            "organization",
            "organization_id",
            "organizational_unit",
            "postal_code",
            "province",
            "serial_number",
            "street_address",
            "surname",
        ]
        nullable_fields = [
            "common_name",
            "country",
            "domain_component",
            "email_address",
            "given_name",
            "jurisdiction_country",
            "jurisdiction_locality",
            "jurisdiction_province",
            "locality",
            "organization",
            "organization_id",
            "organizational_unit",
            "postal_code",
            "province",
            "serial_number",
            "street_address",
            "surname",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class RealportTypedDict(TypedDict):
    hardware_id: NotRequired[int]
    hardware_version: NotRequired[int]
    num_ports: NotRequired[int]
    product_name: NotRequired[str]
    software_version: NotRequired[int]
    unpatched_etherlite: NotRequired[bool]
    vpd: NotRequired[Dict[str, str]]


class Realport(BaseModel):
    hardware_id: Optional[int] = None

    hardware_version: Optional[int] = None

    num_ports: Optional[int] = None

    product_name: Optional[str] = None

    software_version: Optional[int] = None

    unpatched_etherlite: Optional[bool] = None

    vpd: Optional[Dict[str, str]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .crudupdateinputbody import CrudUpdateInputBody, CrudUpdateInputBodyTypedDict
from .responseenvelopecollection import (
    ResponseEnvelopeCollection,
    ResponseEnvelopeCollectionTypedDict,
)
from censys_platform.types import BaseModel
from censys_platform.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3CollectionsCrudUpdateGlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class V3CollectionsCrudUpdateGlobals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class V3CollectionsCrudUpdateRequestTypedDict(TypedDict):
    collection_uid: str
    r"""The UID for the collection"""
    organization_id: NotRequired[str]
    r"""The ID of a Censys organization to associate the request with. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""
    crud_update_input_body: NotRequired[CrudUpdateInputBodyTypedDict]


class V3CollectionsCrudUpdateRequest(BaseModel):
    collection_uid: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UID for the collection"""

    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The ID of a Censys organization to associate the request with. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""

    crud_update_input_body: Annotated[
        Optional[CrudUpdateInputBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None


class V3CollectionsCrudUpdateResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResponseEnvelopeCollectionTypedDict


class V3CollectionsCrudUpdateResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResponseEnvelopeCollection



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SevenDaysToDieTypedDict(TypedDict):
    game_name: NotRequired[str]
    game_type: NotRequired[str]
    region: NotRequired[str]
    server_url: NotRequired[str]
    server_version: NotRequired[str]
    steam_id: NotRequired[str]
    version: NotRequired[str]


class SevenDaysToDie(BaseModel):
    game_name: Optional[str] = None

    game_type: Optional[str] = None

    region: Optional[str] = None

    server_url: Optional[str] = None

    server_version: Optional[str] = None

    steam_id: Optional[str] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class X11TypedDict(TypedDict):
    refusal_reason: NotRequired[str]
    requires_authentication: NotRequired[bool]
    vendor: NotRequired[str]
    version: NotRequired[str]


class X11(BaseModel):
    refusal_reason: Optional[str] = None

    requires_authentication: Optional[bool] = None

    vendor: Optional[str] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing_extensions import TypedDict


class SearchAggregateResponseBucketTypedDict(TypedDict):
    count: int
    key: str


class SearchAggregateResponseBucket(BaseModel):
    count: int

    key: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ct_record import CtRecord, CtRecordTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class CtTypedDict(TypedDict):
    entries: NotRequired[Dict[str, CtRecordTypedDict]]


class Ct(BaseModel):
    entries: Optional[Dict[str, CtRecord]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CiscoIpslaHandshakeMessageTypedDict(TypedDict):
    ip: NotRequired[str]
    length: NotRequired[int]
    port: NotRequired[int]
    type: NotRequired[int]


class CiscoIpslaHandshakeMessage(BaseModel):
    ip: Optional[str] = None

    length: Optional[int] = None

    port: Optional[int] = None

    type: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EcdsaPublicKeyTypedDict(TypedDict):
    b: NotRequired[str]
    curve: NotRequired[str]
    gx: NotRequired[str]
    gy: NotRequired[str]
    length: NotRequired[int]
    n: NotRequired[str]
    p: NotRequired[str]
    pub: NotRequired[str]
    x: NotRequired[str]
    y: NotRequired[str]


class EcdsaPublicKey(BaseModel):
    b: Optional[str] = None

    curve: Optional[str] = None

    gx: Optional[str] = None

    gy: Optional[str] = None

    length: Optional[int] = None

    n: Optional[str] = None

    p: Optional[str] = None

    pub: Optional[str] = None

    x: Optional[str] = None

    y: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SnmpPhysicalTypedDict(TypedDict):
    firmware_rev: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.9 - Firmware revision string"""
    hardware_rev: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.8 - Hardware revision string"""
    mfg_name: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.12 - Name of mfg"""
    model_name: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.13 - Model name of component"""
    name: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.7 - Entity name"""
    serial_num: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.11 - Serial number string"""
    software_rev: NotRequired[str]
    r"""1.3.6.1.2.1.47.1.1.1.1.10 - Software revision string"""


class SnmpPhysical(BaseModel):
    firmware_rev: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.9 - Firmware revision string"""

    hardware_rev: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.8 - Hardware revision string"""

    mfg_name: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.12 - Name of mfg"""

    model_name: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.13 - Model name of component"""

    name: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.7 - Entity name"""

    serial_num: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.11 - Serial number string"""

    software_rev: Optional[str] = None
    r"""1.3.6.1.2.1.47.1.1.1.1.10 - Software revision string"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chromecast_namespace import ChromecastNamespace, ChromecastNamespaceTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ChromecastApplicationTypedDict(TypedDict):
    app_id: NotRequired[str]
    app_type: NotRequired[str]
    display_name: NotRequired[str]
    namespaces: NotRequired[Nullable[List[ChromecastNamespaceTypedDict]]]
    session_id: NotRequired[str]
    transport_id: NotRequired[str]


class ChromecastApplication(BaseModel):
    app_id: Optional[str] = None

    app_type: Optional[str] = None

    display_name: Optional[str] = None

    namespaces: OptionalNullable[List[ChromecastNamespace]] = UNSET

    session_id: Optional[str] = None

    transport_id: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "app_id",
            "app_type",
            "display_name",
            "namespaces",
            "session_id",
            "transport_id",
        ]
        nullable_fields = ["namespaces"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SearchAggregateInputBodyTypedDict(TypedDict):
    field: str
    r"""field to aggregate by"""
    number_of_buckets: int
    r"""number of buckets to split results into"""
    query: str
    r"""CenQL query string to search upon"""
    count_by_level: NotRequired[str]
    r"""Specifies which document level's count is returned per term bucket, primarily for nested fields. This is the same functionality available in the Count By dropdown in the Report Builder UI. When aggregating on nested fields like 'host.services.port': empty string (default) counts documents at the deepest level containing the field; '.' counts root documents (e.g. counts matching 'host'); 'host.services' counts documents at the specified nested level."""
    filter_by_query: NotRequired[bool]
    r"""Controls whether aggregation results are limited to values that match the query. When true, only field values that satisfy the query constraints are included in aggregation counts. When false, aggregation includes all field values from records that match the query, even if those specific field values don't match the query constraints. For example, if the query is 'host.services.protocol=SSH' and you are aggregating by 'host.services.port' - when true, only shows SSH ports; when false, shows all ports on hosts that have SSH services."""


class SearchAggregateInputBody(BaseModel):
    field: str
    r"""field to aggregate by"""

    number_of_buckets: int
    r"""number of buckets to split results into"""

    query: str
    r"""CenQL query string to search upon"""

    count_by_level: Optional[str] = None
    r"""Specifies which document level's count is returned per term bucket, primarily for nested fields. This is the same functionality available in the Count By dropdown in the Report Builder UI. When aggregating on nested fields like 'host.services.port': empty string (default) counts documents at the deepest level containing the field; '.' counts root documents (e.g. counts matching 'host'); 'host.services' counts documents at the specified nested level."""

    filter_by_query: Optional[bool] = False
    r"""Controls whether aggregation results are limited to values that match the query. When true, only field values that satisfy the query constraints are included in aggregation counts. When false, aggregation includes all field values from records that match the query, even if those specific field values don't match the query constraints. For example, if the query is 'host.services.protocol=SSH' and you are aggregating by 'host.services.port' - when true, only shows SSH ports; when false, shows all ports on hosts that have SSH services."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SnmpInterfacesTypedDict(TypedDict):
    num_ifaces: NotRequired[int]
    r"""1.3.6.1.2.1.2.1 - Number of network interfaces"""


class SnmpInterfaces(BaseModel):
    num_ifaces: Optional[int] = None
    r"""1.3.6.1.2.1.2.1 - Number of network interfaces"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStoreTypedDict(TypedDict):
    reserved_in_bytes: NotRequired[int]
    size_in_bytes: NotRequired[int]


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesStore(BaseModel):
    reserved_in_bytes: Optional[int] = None

    size_in_bytes: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WeblogicT3TypedDict(TypedDict):
    error: NotRequired[str]
    error_message: NotRequired[str]
    weblogic_version: NotRequired[str]


class WeblogicT3(BaseModel):
    error: Optional[str] = None

    error_message: Optional[str] = None

    weblogic_version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PgbouncerStartupCapabilitiesTypedDict(TypedDict):
    v2: NotRequired[bool]
    v3: NotRequired[bool]
    v4: NotRequired[bool]


class PgbouncerStartupCapabilities(BaseModel):
    v2: Optional[bool] = None

    v3: Optional[bool] = None

    v4: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cryptsetup import CryptSetup, CryptSetupTypedDict
from .murmur_murmurversion import MurmurMurmurVersion, MurmurMurmurVersionTypedDict
from .murmurmessage import MurmurMessage, MurmurMessageTypedDict
from .reject import Reject, RejectTypedDict
from .serverconfig import ServerConfig, ServerConfigTypedDict
from .serversync import ServerSync, ServerSyncTypedDict
from .textmessage import TextMessage, TextMessageTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class MurmurTypedDict(TypedDict):
    crypt_setup: NotRequired[CryptSetupTypedDict]
    murmur_messages: NotRequired[Nullable[List[MurmurMessageTypedDict]]]
    reject: NotRequired[RejectTypedDict]
    server_config: NotRequired[ServerConfigTypedDict]
    server_sync: NotRequired[ServerSyncTypedDict]
    text_messages: NotRequired[Nullable[List[TextMessageTypedDict]]]
    version: NotRequired[MurmurMurmurVersionTypedDict]


class Murmur(BaseModel):
    crypt_setup: Optional[CryptSetup] = None

    murmur_messages: OptionalNullable[List[MurmurMessage]] = UNSET

    reject: Optional[Reject] = None

    server_config: Optional[ServerConfig] = None

    server_sync: Optional[ServerSync] = None

    text_messages: OptionalNullable[List[TextMessage]] = UNSET

    version: Optional[MurmurMurmurVersion] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "crypt_setup",
            "murmur_messages",
            "reject",
            "server_config",
            "server_sync",
            "text_messages",
            "version",
        ]
        nullable_fields = ["murmur_messages", "text_messages"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ventrilo_header import VentriloHeader, VentriloHeaderTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class VentriloMessageTypedDict(TypedDict):
    body: NotRequired[str]
    error: NotRequired[str]
    header: NotRequired[VentriloHeaderTypedDict]


class VentriloMessage(BaseModel):
    body: Optional[str] = None

    error: Optional[str] = None

    header: Optional[VentriloHeader] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class HikvisionPlatformLibraryTypedDict(TypedDict):
    name: NotRequired[str]
    version: NotRequired[str]


class HikvisionPlatformLibrary(BaseModel):
    name: Optional[str] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ServiceIDTransportProtocol(str, Enum):
    UNKNOWN = ""
    TCP = "tcp"
    UDP = "udp"
    ICMP = "icmp"
    QUIC = "quic"


class ServiceIDTypedDict(TypedDict):
    ip: NotRequired[str]
    port: NotRequired[int]
    protocol: NotRequired[str]
    transport_protocol: NotRequired[ServiceIDTransportProtocol]


class ServiceID(BaseModel):
    ip: Optional[str] = None

    port: Optional[int] = None

    protocol: Optional[str] = None

    transport_protocol: Optional[ServiceIDTransportProtocol] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class AnyConnectTypedDict(TypedDict):
    aggregate_auth_version: NotRequired[int]
    r"""Version number indicated by the response for config-auth exchange"""
    auth_methods: NotRequired[Nullable[List[str]]]
    r"""Supported methods for users to enter credentials for this VPN"""
    groups: NotRequired[Nullable[List[str]]]
    r"""List of groups a user can authenticate with to use this VPN"""
    raw: NotRequired[str]
    r"""XML content of the config-auth response"""
    response_type: NotRequired[str]
    r"""Type of the response packet received after initializing the config-auth exchange"""


class AnyConnect(BaseModel):
    aggregate_auth_version: Optional[int] = None
    r"""Version number indicated by the response for config-auth exchange"""

    auth_methods: OptionalNullable[List[str]] = UNSET
    r"""Supported methods for users to enter credentials for this VPN"""

    groups: OptionalNullable[List[str]] = UNSET
    r"""List of groups a user can authenticate with to use this VPN"""

    raw: Optional[str] = None
    r"""XML content of the config-auth response"""

    response_type: Optional[str] = None
    r"""Type of the response packet received after initializing the config-auth exchange"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "aggregate_auth_version",
            "auth_methods",
            "groups",
            "raw",
            "response_type",
        ]
        nullable_fields = ["auth_methods", "groups"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DsaPublicKeyTypedDict(TypedDict):
    g: NotRequired[str]
    p: NotRequired[str]
    q: NotRequired[str]
    y: NotRequired[str]


class DsaPublicKey(BaseModel):
    g: Optional[str] = None

    p: Optional[str] = None

    q: Optional[str] = None

    y: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Ed25519CryptographicKeyTypedDict(TypedDict):
    public_bytes: NotRequired[str]


class Ed25519CryptographicKey(BaseModel):
    public_bytes: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DNSResourceRecordType(str, Enum):
    r"""An enumerated field indicating what type of data is in the \"services.dns.additionals.response\" field. For example, \"A\" signifies that the value in \"services.dns.additionals.response\" is an IPv4 address for the FQDN in \"services.dns.additionals.name\"."""

    UNKNOWN = ""
    A = "a"
    TXT = "txt"
    NS = "ns"


class DNSResourceRecordTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The Fully Qualified Domain Name (FQDN) this RR is for."""
    response: NotRequired[str]
    r"""The RDATA field of the RR."""
    type: NotRequired[DNSResourceRecordType]
    r"""An enumerated field indicating what type of data is in the \"services.dns.additionals.response\" field. For example, \"A\" signifies that the value in \"services.dns.additionals.response\" is an IPv4 address for the FQDN in \"services.dns.additionals.name\"."""


class DNSResourceRecord(BaseModel):
    name: Optional[str] = None
    r"""The Fully Qualified Domain Name (FQDN) this RR is for."""

    response: Optional[str] = None
    r"""The RDATA field of the RR."""

    type: Optional[DNSResourceRecordType] = None
    r"""An enumerated field indicating what type of data is in the \"services.dns.additionals.response\" field. For example, \"A\" signifies that the value in \"services.dns.additionals.response\" is an IPv4 address for the FQDN in \"services.dns.additionals.name\"."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocsTypedDict(TypedDict):
    count: NotRequired[int]
    deleted: NotRequired[int]


class ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesDocs(BaseModel):
    count: Optional[int] = None

    deleted: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .nodeinfov0 import NodeInfoV0, NodeInfoV0TypedDict
from .nodeinfov1 import NodeInfoV1, NodeInfoV1TypedDict
from .nodeinfov2 import NodeInfoV2, NodeInfoV2TypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IotaTypedDict(TypedDict):
    v0_info: NotRequired[NodeInfoV0TypedDict]
    v1_info: NotRequired[NodeInfoV1TypedDict]
    v2_info: NotRequired[NodeInfoV2TypedDict]


class Iota(BaseModel):
    v0_info: Optional[NodeInfoV0] = None

    v1_info: Optional[NodeInfoV1] = None

    v2_info: Optional[NodeInfoV2] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mssql_preloginoptions import MssqlPreloginOptions, MssqlPreloginOptionsTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MssqlTypedDict(TypedDict):
    encrypt_mode: NotRequired[str]
    r"""The negotiated ENCRYPT_MODE with the server"""
    instance_name: NotRequired[str]
    prelogin_options: NotRequired[MssqlPreloginOptionsTypedDict]
    version: NotRequired[str]


class Mssql(BaseModel):
    encrypt_mode: Optional[str] = None
    r"""The negotiated ENCRYPT_MODE with the server"""

    instance_name: Optional[str] = None

    prelogin_options: Optional[MssqlPreloginOptions] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiCommandPayloadCommandNumberTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The human-readable name of the cmd + NetFn"""
    raw: NotRequired[int]
    r"""The raw value of the cmd value"""


class IpmiCommandPayloadCommandNumber(BaseModel):
    name: Optional[str] = None
    r"""The human-readable name of the cmd + NetFn"""

    raw: Optional[int] = None
    r"""The raw value of the cmd value"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .user import User, UserTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class SteamTypedDict(TypedDict):
    broadcasting_active: NotRequired[bool]
    connect_port: NotRequired[int]
    content_cache_port: NotRequired[int]
    download_lan_peer_group: NotRequired[int]
    enabled_services: NotRequired[int]
    euniverse: NotRequired[int]
    games_running: NotRequired[bool]
    hostname: NotRequired[str]
    ip_addresses: NotRequired[Nullable[List[str]]]
    is64bit: NotRequired[bool]
    mac_addresses: NotRequired[Nullable[List[str]]]
    min_version: NotRequired[int]
    ostype: NotRequired[int]
    public_ip_address: NotRequired[str]
    remoteplay_active: NotRequired[bool]
    screen_locked: NotRequired[bool]
    steam_deck: NotRequired[bool]
    steam_version: NotRequired[str]
    supported_services: NotRequired[int]
    users: NotRequired[Nullable[List[UserTypedDict]]]
    version: NotRequired[int]
    vr_active: NotRequired[bool]
    vr_link_caps: NotRequired[str]


class Steam(BaseModel):
    broadcasting_active: Optional[bool] = None

    connect_port: Optional[int] = None

    content_cache_port: Optional[int] = None

    download_lan_peer_group: Optional[int] = None

    enabled_services: Optional[int] = None

    euniverse: Optional[int] = None

    games_running: Optional[bool] = None

    hostname: Optional[str] = None

    ip_addresses: OptionalNullable[List[str]] = UNSET

    is64bit: Optional[bool] = None

    mac_addresses: OptionalNullable[List[str]] = UNSET

    min_version: Optional[int] = None

    ostype: Optional[int] = None

    public_ip_address: Optional[str] = None

    remoteplay_active: Optional[bool] = None

    screen_locked: Optional[bool] = None

    steam_deck: Optional[bool] = None

    steam_version: Optional[str] = None

    supported_services: Optional[int] = None

    users: OptionalNullable[List[User]] = UNSET

    version: Optional[int] = None

    vr_active: Optional[bool] = None

    vr_link_caps: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "broadcasting_active",
            "connect_port",
            "content_cache_port",
            "download_lan_peer_group",
            "enabled_services",
            "euniverse",
            "games_running",
            "hostname",
            "ip_addresses",
            "is64bit",
            "mac_addresses",
            "min_version",
            "ostype",
            "public_ip_address",
            "remoteplay_active",
            "screen_locked",
            "steam_deck",
            "steam_version",
            "supported_services",
            "users",
            "version",
            "vr_active",
            "vr_link_caps",
        ]
        nullable_fields = ["ip_addresses", "mac_addresses", "users"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrMLTypedDict(
    TypedDict
):
    enabled: NotRequired[str]
    machine_memory: NotRequired[str]
    max_open_jobs: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeAttrML(BaseModel):
    enabled: Optional[str] = None

    machine_memory: Optional[str] = None

    max_open_jobs: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RsaPublicKeyTypedDict(TypedDict):
    exponent: NotRequired[int]
    r"""The RSA key's public exponent (e)."""
    length: NotRequired[int]
    r"""Bit-length of the RSA modulus."""
    modulus: NotRequired[str]
    r"""The RSA key's modulus (n) in big-endian encoding."""


class RsaPublicKey(BaseModel):
    exponent: Optional[int] = None
    r"""The RSA key's public exponent (e)."""

    length: Optional[int] = None
    r"""Bit-length of the RSA modulus."""

    modulus: Optional[str] = None
    r"""The RSA key's modulus (n) in big-endian encoding."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TrackedScanTaskStatus(str, Enum):
    UNKNOWN = ""
    SCANNING = "scanning"
    SCANNED = "scanned"
    REJECTED = "rejected"
    TIMED_OUT = "timed_out"
    COMPLETED = "completed"
    IGNORED = "ignored"


class TrackedScanTaskTypedDict(TypedDict):
    description: NotRequired[str]
    status: NotRequired[TrackedScanTaskStatus]
    update_time: NotRequired[str]


class TrackedScanTask(BaseModel):
    description: Optional[str] = None

    status: Optional[TrackedScanTaskStatus] = None

    update_time: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KubernetesVersionInfoTypedDict(TypedDict):
    build_date: NotRequired[str]
    r"""Date version was built."""
    compiler: NotRequired[str]
    r"""Go Compiler used"""
    git_commit: NotRequired[str]
    r"""Git commit version built from."""
    git_tree_state: NotRequired[str]
    r"""State of the tree when built."""
    git_version: NotRequired[str]
    go_version: NotRequired[str]
    r"""Version of GO used to build version."""
    major: NotRequired[str]
    r"""Kubernetes major version"""
    minor: NotRequired[str]
    r"""Kubernetes minor version"""
    platform: NotRequired[str]
    r"""Platform compiled for"""


class KubernetesVersionInfo(BaseModel):
    build_date: Optional[str] = None
    r"""Date version was built."""

    compiler: Optional[str] = None
    r"""Go Compiler used"""

    git_commit: Optional[str] = None
    r"""Git commit version built from."""

    git_tree_state: Optional[str] = None
    r"""State of the tree when built."""

    git_version: Optional[str] = None

    go_version: Optional[str] = None
    r"""Version of GO used to build version."""

    major: Optional[str] = None
    r"""Kubernetes major version"""

    minor: Optional[str] = None
    r"""Kubernetes minor version"""

    platform: Optional[str] = None
    r"""Platform compiled for"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .serviceid import ServiceID, ServiceIDTypedDict
from .trackedscan_scantarget_hostnameport import (
    TrackedScanScanTargetHostnamePort,
    TrackedScanScanTargetHostnamePortTypedDict,
)
from .trackedscan_scantarget_hostport import (
    TrackedScanScanTargetHostPort,
    TrackedScanScanTargetHostPortTypedDict,
)
from .weborigin import WebOrigin, WebOriginTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TrackedScanScanTargetTypedDict(TypedDict):
    host_port: NotRequired[TrackedScanScanTargetHostPortTypedDict]
    hostname_port: NotRequired[TrackedScanScanTargetHostnamePortTypedDict]
    service_id: NotRequired[ServiceIDTypedDict]
    web_origin: NotRequired[WebOriginTypedDict]


class TrackedScanScanTarget(BaseModel):
    host_port: Optional[TrackedScanScanTargetHostPort] = None

    hostname_port: Optional[TrackedScanScanTargetHostnamePort] = None

    service_id: Optional[ServiceID] = None

    web_origin: Optional[WebOrigin] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RecordType(str, Enum):
    UNKNOWN = ""
    A = "a"
    AAAA = "aaaa"


class HostDNSForwardResolutionTypedDict(TypedDict):
    name: NotRequired[str]
    record_type: NotRequired[RecordType]
    resolve_time: NotRequired[str]
    server: NotRequired[str]


class HostDNSForwardResolution(BaseModel):
    name: Optional[str] = None

    record_type: Optional[RecordType] = None

    resolve_time: Optional[str] = None

    server: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class KubernetesRoleRuleTypedDict(TypedDict):
    api_groups: NotRequired[Nullable[List[str]]]
    r"""APIGroups is the name of the APIGroup that contains the resources. If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed."""
    resources: NotRequired[Nullable[List[str]]]
    r"""Resources is a list of resources this rule applies to. ResourceAll represents all resources"""
    verbs: NotRequired[Nullable[List[str]]]
    r"""Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule. VerbAll represents all kinds."""


class KubernetesRoleRule(BaseModel):
    api_groups: OptionalNullable[List[str]] = UNSET
    r"""APIGroups is the name of the APIGroup that contains the resources. If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed."""

    resources: OptionalNullable[List[str]] = UNSET
    r"""Resources is a list of resources this rule applies to. ResourceAll represents all resources"""

    verbs: OptionalNullable[List[str]] = UNSET
    r"""Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule. VerbAll represents all kinds."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["api_groups", "resources", "verbs"]
        nullable_fields = ["api_groups", "resources", "verbs"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class HidVertxTypedDict(TypedDict):
    firmware_date: NotRequired[str]
    id: NotRequired[str]
    ip: NotRequired[str]
    mac_address: NotRequired[str]
    make_model: NotRequired[str]
    model: NotRequired[str]
    version: NotRequired[str]


class HidVertx(BaseModel):
    firmware_date: Optional[str] = None

    id: Optional[str] = None

    ip: Optional[str] = None

    mac_address: Optional[str] = None

    make_model: Optional[str] = None

    model: Optional[str] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiCapabilitiesExtendedCapabilitiesTypedDict(TypedDict):
    supports_ipmi_v1_5: NotRequired[bool]
    r"""True if IPMI v1.5 is supported"""
    supports_ipmi_v2_0: NotRequired[bool]
    r"""True if IPMI v2.0 is supported"""


class IpmiCapabilitiesExtendedCapabilities(BaseModel):
    supports_ipmi_v1_5: Optional[bool] = None
    r"""True if IPMI v1.5 is supported"""

    supports_ipmi_v2_0: Optional[bool] = None
    r"""True if IPMI v2.0 is supported"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .prometheus_response_activetarget_discoveredlabels import (
    PrometheusResponseActiveTargetDiscoveredLabels,
    PrometheusResponseActiveTargetDiscoveredLabelsTypedDict,
)
from .prometheus_response_activetarget_labels import (
    PrometheusResponseActiveTargetLabels,
    PrometheusResponseActiveTargetLabelsTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PrometheusResponseActiveTargetTypedDict(TypedDict):
    discovered_labels: NotRequired[
        PrometheusResponseActiveTargetDiscoveredLabelsTypedDict
    ]
    health: NotRequired[str]
    r"""Whether target is up or down."""
    labels: NotRequired[PrometheusResponseActiveTargetLabelsTypedDict]
    last_error: NotRequired[str]
    r"""Last error that occurred within target."""
    last_scrape: NotRequired[str]
    r"""Last time Prometheus scraped target."""
    scrape_url: NotRequired[str]
    r"""URL that Prometheus scraped."""


class PrometheusResponseActiveTarget(BaseModel):
    discovered_labels: Optional[PrometheusResponseActiveTargetDiscoveredLabels] = None

    health: Optional[str] = None
    r"""Whether target is up or down."""

    labels: Optional[PrometheusResponseActiveTargetLabels] = None

    last_error: Optional[str] = None
    r"""Last error that occurred within target."""

    last_scrape: Optional[str] = None
    r"""Last time Prometheus scraped target."""

    scrape_url: Optional[str] = None
    r"""URL that Prometheus scraped."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PptpResponseInfoTypedDict(TypedDict):
    code: NotRequired[int]
    meaning: NotRequired[str]


class PptpResponseInfo(BaseModel):
    code: Optional[int] = None

    meaning: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ike_v1 import IkeV1, IkeV1TypedDict
from .ike_v2 import IkeV2, IkeV2TypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IkeTypedDict(TypedDict):
    v1: NotRequired[IkeV1TypedDict]
    v2: NotRequired[IkeV2TypedDict]


class Ike(BaseModel):
    v1: Optional[IkeV1] = None

    v2: Optional[IkeV2] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MinecraftTypedDict(TypedDict):
    motd: NotRequired[str]
    players_max: NotRequired[int]
    players_online: NotRequired[int]
    protocol_version: NotRequired[str]
    server_version: NotRequired[str]


class Minecraft(BaseModel):
    motd: Optional[str] = None

    players_max: Optional[int] = None

    players_online: Optional[int] = None

    protocol_version: Optional[str] = None

    server_version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class NtlmInfoTypedDict(TypedDict):
    always_sign_supported: NotRequired[bool]
    challenge_type: NotRequired[int]
    dns_domain_name: NotRequired[str]
    dns_server_name: NotRequired[str]
    dns_tree_name: NotRequired[str]
    encryption_128bit_supported: NotRequired[bool]
    encryption_56bit_supported: NotRequired[bool]
    netbios_computer_name: NotRequired[str]
    netbios_domain_name: NotRequired[str]
    ntlm1_supported: NotRequired[bool]
    ntlm2_supported: NotRequired[bool]
    ntlm_version: NotRequired[int]
    os_version: NotRequired[str]
    target_name: NotRequired[str]


class NtlmInfo(BaseModel):
    always_sign_supported: Optional[bool] = None

    challenge_type: Optional[int] = None

    dns_domain_name: Optional[str] = None

    dns_server_name: Optional[str] = None

    dns_tree_name: Optional[str] = None

    encryption_128bit_supported: Optional[bool] = None

    encryption_56bit_supported: Optional[bool] = None

    netbios_computer_name: Optional[str] = None

    netbios_domain_name: Optional[str] = None

    ntlm1_supported: Optional[bool] = None

    ntlm2_supported: Optional[bool] = None

    ntlm_version: Optional[int] = None

    os_version: Optional[str] = None

    target_name: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chromedevtools import ChromeDevtools, ChromeDevtoolsTypedDict
from .cobaltstrike import CobaltStrike, CobaltStrikeTypedDict
from .elasticsearch import ElasticSearch, ElasticSearchTypedDict
from .fortigate import Fortigate, FortigateTypedDict
from .graphql import Graphql, GraphqlTypedDict
from .http import HTTP, HTTPTypedDict
from .ivantiavalanche import IvantiAvalanche, IvantiAvalancheTypedDict
from .kubernetes import Kubernetes, KubernetesTypedDict
from .ollama import Ollama, OllamaTypedDict
from .opendirectory import OpenDirectory, OpenDirectoryTypedDict
from .plexmediaserver import PlexMediaServer, PlexMediaServerTypedDict
from .pprof import Pprof, PprofTypedDict
from .prometheus import Prometheus, PrometheusTypedDict
from .prometheustarget import PrometheusTarget, PrometheusTargetTypedDict
from .redlionweb import RedlionWeb, RedlionWebTypedDict
from .scadaview import ScadaView, ScadaViewTypedDict
from .screenshot import Screenshot, ScreenshotTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class EndpointScanStateTransportProtocol(str, Enum):
    UNKNOWN = ""
    TCP = "tcp"
    UDP = "udp"
    ICMP = "icmp"
    QUIC = "quic"


class EndpointScanStateTypedDict(TypedDict):
    banner: NotRequired[str]
    banner_hash_sha256: NotRequired[str]
    chrome_devtools: NotRequired[ChromeDevtoolsTypedDict]
    cobalt_strike: NotRequired[CobaltStrikeTypedDict]
    elasticsearch: NotRequired[ElasticSearchTypedDict]
    endpoint_type: NotRequired[str]
    fortigate: NotRequired[FortigateTypedDict]
    graphql: NotRequired[GraphqlTypedDict]
    hostname: NotRequired[str]
    http: NotRequired[HTTPTypedDict]
    ip: NotRequired[str]
    ivanti_avalanche: NotRequired[IvantiAvalancheTypedDict]
    kubernetes: NotRequired[KubernetesTypedDict]
    ollama: NotRequired[OllamaTypedDict]
    open_directory: NotRequired[OpenDirectoryTypedDict]
    path: NotRequired[str]
    plex_media_server: NotRequired[PlexMediaServerTypedDict]
    port: NotRequired[int]
    pprof: NotRequired[PprofTypedDict]
    prometheus: NotRequired[PrometheusTypedDict]
    prometheus_target: NotRequired[PrometheusTargetTypedDict]
    redlion_web: NotRequired[RedlionWebTypedDict]
    scada_view: NotRequired[ScadaViewTypedDict]
    scan_time: NotRequired[str]
    screenshots: NotRequired[Nullable[List[ScreenshotTypedDict]]]
    transport_protocol: NotRequired[EndpointScanStateTransportProtocol]


class EndpointScanState(BaseModel):
    banner: Optional[str] = None

    banner_hash_sha256: Optional[str] = None

    chrome_devtools: Optional[ChromeDevtools] = None

    cobalt_strike: Optional[CobaltStrike] = None

    elasticsearch: Optional[ElasticSearch] = None

    endpoint_type: Optional[str] = None

    fortigate: Optional[Fortigate] = None

    graphql: Optional[Graphql] = None

    hostname: Optional[str] = None

    http: Optional[HTTP] = None

    ip: Optional[str] = None

    ivanti_avalanche: Optional[IvantiAvalanche] = None

    kubernetes: Optional[Kubernetes] = None

    ollama: Optional[Ollama] = None

    open_directory: Optional[OpenDirectory] = None

    path: Optional[str] = None

    plex_media_server: Optional[PlexMediaServer] = None

    port: Optional[int] = None

    pprof: Optional[Pprof] = None

    prometheus: Optional[Prometheus] = None

    prometheus_target: Optional[PrometheusTarget] = None

    redlion_web: Optional[RedlionWeb] = None

    scada_view: Optional[ScadaView] = None

    scan_time: Optional[str] = None

    screenshots: OptionalNullable[List[Screenshot]] = UNSET

    transport_protocol: Optional[EndpointScanStateTransportProtocol] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "banner",
            "banner_hash_sha256",
            "chrome_devtools",
            "cobalt_strike",
            "elasticsearch",
            "endpoint_type",
            "fortigate",
            "graphql",
            "hostname",
            "http",
            "ip",
            "ivanti_avalanche",
            "kubernetes",
            "ollama",
            "open_directory",
            "path",
            "plex_media_server",
            "port",
            "pprof",
            "prometheus",
            "prometheus_target",
            "redlion_web",
            "scada_view",
            "scan_time",
            "screenshots",
            "transport_protocol",
        ]
        nullable_fields = ["screenshots"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .certificateasset import CertificateAsset, CertificateAssetTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeCertificateAssetTypedDict(TypedDict):
    result: NotRequired[CertificateAssetTypedDict]


class ResponseEnvelopeCertificateAsset(BaseModel):
    result: Optional[CertificateAsset] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dsapublickey import DsaPublicKey, DsaPublicKeyTypedDict
from .ecdsapublickey import EcdsaPublicKey, EcdsaPublicKeyTypedDict
from .keyalgorithm import KeyAlgorithm, KeyAlgorithmTypedDict
from .rsapublickey import RsaPublicKey, RsaPublicKeyTypedDict
from .unrecognizedpublickey import UnrecognizedPublicKey, UnrecognizedPublicKeyTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SubjectKeyInfoTypedDict(TypedDict):
    dsa: NotRequired[DsaPublicKeyTypedDict]
    ecdsa: NotRequired[EcdsaPublicKeyTypedDict]
    fingerprint_sha256: NotRequired[str]
    r"""The SHA-256 digest of the certificate's DER-encoded SubjectPublicKeyInfo."""
    key_algorithm: NotRequired[KeyAlgorithmTypedDict]
    rsa: NotRequired[RsaPublicKeyTypedDict]
    unrecognized: NotRequired[UnrecognizedPublicKeyTypedDict]


class SubjectKeyInfo(BaseModel):
    dsa: Optional[DsaPublicKey] = None

    ecdsa: Optional[EcdsaPublicKey] = None

    fingerprint_sha256: Optional[str] = None
    r"""The SHA-256 digest of the certificate's DER-encoded SubjectPublicKeyInfo."""

    key_algorithm: Optional[KeyAlgorithm] = None

    rsa: Optional[RsaPublicKey] = None

    unrecognized: Optional[UnrecognizedPublicKey] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ipmi_sessionheader_authtype import (
    IpmiSessionHeaderAuthType,
    IpmiSessionHeaderAuthTypeTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiSessionHeaderTypedDict(TypedDict):
    auth_code: NotRequired[str]
    r"""The 16-byte authentication code; not present if auth_type is None."""
    auth_type: NotRequired[IpmiSessionHeaderAuthTypeTypedDict]
    session_id: NotRequired[int]
    r"""The ID of this sessiod."""
    session_sequence_number: NotRequired[int]
    r"""The session sequence number of this packet in the session"""


class IpmiSessionHeader(BaseModel):
    auth_code: Optional[str] = None
    r"""The 16-byte authentication code; not present if auth_type is None."""

    auth_type: Optional[IpmiSessionHeaderAuthType] = None

    session_id: Optional[int] = None
    r"""The ID of this sessiod."""

    session_sequence_number: Optional[int] = None
    r"""The session sequence number of this packet in the session"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpDomainParametersTypedDict(TypedDict):
    domain_protocol_version: NotRequired[int]
    max_channel_ids: NotRequired[int]
    max_mcspdu_size: NotRequired[int]
    max_provider_height: NotRequired[int]
    max_token_ids: NotRequired[int]
    max_user_id_channels: NotRequired[int]
    min_throughput: NotRequired[int]
    num_priorities: NotRequired[int]


class RdpDomainParameters(BaseModel):
    domain_protocol_version: Optional[int] = None

    max_channel_ids: Optional[int] = None

    max_mcspdu_size: Optional[int] = None

    max_provider_height: Optional[int] = None

    max_token_ids: Optional[int] = None

    max_user_id_channels: Optional[int] = None

    min_throughput: Optional[int] = None

    num_priorities: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CobaltStrikeHTTPConfigTypedDict(TypedDict):
    client: NotRequired[str]
    uri: NotRequired[str]
    verb: NotRequired[str]


class CobaltStrikeHTTPConfig(BaseModel):
    client: Optional[str] = None

    uri: Optional[str] = None

    verb: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .contact import Contact, ContactTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class OrganizationTypedDict(TypedDict):
    abuse_contacts: NotRequired[Nullable[List[ContactTypedDict]]]
    address: NotRequired[str]
    admin_contacts: NotRequired[Nullable[List[ContactTypedDict]]]
    city: NotRequired[str]
    country: NotRequired[str]
    handle: NotRequired[str]
    name: NotRequired[str]
    postal_code: NotRequired[str]
    state: NotRequired[str]
    street: NotRequired[str]
    tech_contacts: NotRequired[Nullable[List[ContactTypedDict]]]


class Organization(BaseModel):
    abuse_contacts: OptionalNullable[List[Contact]] = UNSET

    address: Optional[str] = None

    admin_contacts: OptionalNullable[List[Contact]] = UNSET

    city: Optional[str] = None

    country: Optional[str] = None

    handle: Optional[str] = None

    name: Optional[str] = None

    postal_code: Optional[str] = None

    state: Optional[str] = None

    street: Optional[str] = None

    tech_contacts: OptionalNullable[List[Contact]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "abuse_contacts",
            "address",
            "admin_contacts",
            "city",
            "country",
            "handle",
            "name",
            "postal_code",
            "state",
            "street",
            "tech_contacts",
        ]
        nullable_fields = ["abuse_contacts", "admin_contacts", "tech_contacts"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FloatValueTypedDict(TypedDict):
    value: NotRequired[float]


class FloatValue(BaseModel):
    value: Optional[float] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .upnp_service import UpnpService, UpnpServiceTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class UpnpDeviceTypedDict(TypedDict):
    device_type: NotRequired[str]
    friendly_name: NotRequired[str]
    id: NotRequired[int]
    r"""Censys-generated IDs representing a device tree"""
    manufacturer: NotRequired[str]
    manufacturer_url: NotRequired[str]
    model_description: NotRequired[str]
    model_name: NotRequired[str]
    model_number: NotRequired[str]
    model_url: NotRequired[str]
    parent_id: NotRequired[int]
    presentation_url: NotRequired[str]
    serial_number: NotRequired[str]
    service_list: NotRequired[Nullable[List[UpnpServiceTypedDict]]]
    udn: NotRequired[str]
    upc: NotRequired[str]


class UpnpDevice(BaseModel):
    device_type: Optional[str] = None

    friendly_name: Optional[str] = None

    id: Optional[int] = None
    r"""Censys-generated IDs representing a device tree"""

    manufacturer: Optional[str] = None

    manufacturer_url: Optional[str] = None

    model_description: Optional[str] = None

    model_name: Optional[str] = None

    model_number: Optional[str] = None

    model_url: Optional[str] = None

    parent_id: Optional[int] = None

    presentation_url: Optional[str] = None

    serial_number: Optional[str] = None

    service_list: OptionalNullable[List[UpnpService]] = UNSET

    udn: Optional[str] = None

    upc: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "device_type",
            "friendly_name",
            "id",
            "manufacturer",
            "manufacturer_url",
            "model_description",
            "model_name",
            "model_number",
            "model_url",
            "parent_id",
            "presentation_url",
            "serial_number",
            "service_list",
            "udn",
            "upc",
        ]
        nullable_fields = ["service_list"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dhcpdiscover_responseparams import (
    DhcpdiscoverResponseParams,
    DhcpdiscoverResponseParamsTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DhcpdiscoverTypedDict(TypedDict):
    method: NotRequired[str]
    params: NotRequired[DhcpdiscoverResponseParamsTypedDict]


class Dhcpdiscover(BaseModel):
    method: Optional[str] = None

    params: Optional[DhcpdiscoverResponseParams] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .errordetail import ErrorDetail
from censys_platform.models import SDKBaseError
from censys_platform.types import BaseModel, OptionalNullable, UNSET
from dataclasses import dataclass, field
import httpx
from typing import List, Optional


class ErrorModelData(BaseModel):
    detail: Optional[str] = None
    r"""A human-readable explanation specific to this occurrence of the problem."""

    errors: OptionalNullable[List[ErrorDetail]] = UNSET
    r"""Optional list of individual error details"""

    instance: Optional[str] = None
    r"""A URI reference that identifies the specific occurrence of the problem."""

    status: Optional[int] = None
    r"""HTTP status code"""

    title: Optional[str] = None
    r"""A short, human-readable summary of the problem type. This value should not change between occurrences of the error."""

    type: Optional[str] = "about:blank"
    r"""A URI reference to human-readable documentation for the error."""


@dataclass(unsafe_hash=True)
class ErrorModel(SDKBaseError):
    data: ErrorModelData = field(hash=False)

    def __init__(
        self,
        data: ErrorModelData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ipmi_commandpayload_commandnumber import (
    IpmiCommandPayloadCommandNumber,
    IpmiCommandPayloadCommandNumberTypedDict,
)
from .ipmi_commandpayload_packednetfn import (
    IpmiCommandPayloadPackedNetFn,
    IpmiCommandPayloadPackedNetFnTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiCommandPayloadTypedDict(TypedDict):
    checksum_error: NotRequired[bool]
    r"""This is set to true if the values of chk1 / chk2 do not match the command data"""
    data: NotRequired[str]
    r"""The raw data. On success, this should be the value of the GetAuthenticationCapabilities resopnse"""
    ipmi_command_number: NotRequired[IpmiCommandPayloadCommandNumberTypedDict]
    network_function_code: NotRequired[IpmiCommandPayloadPackedNetFnTypedDict]
    requestor_sequence_number: NotRequired[int]
    r"""The request sequence number."""


class IpmiCommandPayload(BaseModel):
    checksum_error: Optional[bool] = None
    r"""This is set to true if the values of chk1 / chk2 do not match the command data"""

    data: Optional[str] = None
    r"""The raw data. On success, this should be the value of the GetAuthenticationCapabilities resopnse"""

    ipmi_command_number: Optional[IpmiCommandPayloadCommandNumber] = None

    network_function_code: Optional[IpmiCommandPayloadPackedNetFn] = None

    requestor_sequence_number: Optional[int] = None
    r"""The request sequence number."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CPELifeCycleTypedDict(TypedDict):
    end_of_life: NotRequired[bool]
    end_of_life_date: NotRequired[str]
    release_date: NotRequired[str]


class CPELifeCycle(BaseModel):
    end_of_life: Optional[bool] = None

    end_of_life_date: Optional[str] = None

    release_date: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .network import Network, NetworkTypedDict
from .organization import Organization, OrganizationTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WhoisTypedDict(TypedDict):
    network: NotRequired[NetworkTypedDict]
    organization: NotRequired[OrganizationTypedDict]


class Whois(BaseModel):
    network: Optional[Network] = None

    organization: Optional[Organization] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .keyalgorithm import KeyAlgorithm, KeyAlgorithmTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SignatureTypedDict(TypedDict):
    self_signed: NotRequired[bool]
    r"""Whether the certificate was signed by its own key."""
    signature_algorithm: NotRequired[KeyAlgorithmTypedDict]
    valid: NotRequired[bool]
    r"""Whether the signature is valid."""
    value: NotRequired[str]
    r"""Contents of the signature."""


class Signature(BaseModel):
    self_signed: Optional[bool] = None
    r"""Whether the certificate was signed by its own key."""

    signature_algorithm: Optional[KeyAlgorithm] = None

    valid: Optional[bool] = None
    r"""Whether the signature is valid."""

    value: Optional[str] = None
    r"""Contents of the signature."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rocketmq_responseheader import (
    RocketmqResponseHeader,
    RocketmqResponseHeaderTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RocketmqClusterInfoTypedDict(TypedDict):
    header: NotRequired[RocketmqResponseHeaderTypedDict]
    payload: NotRequired[str]


class RocketmqClusterInfo(BaseModel):
    header: Optional[RocketmqResponseHeader] = None

    payload: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .smb_negotiationlog import SmbNegotiationLog, SmbNegotiationLogTypedDict
from .smb_sessionsetuplog import SmbSessionSetupLog, SmbSessionSetupLogTypedDict
from .smb_smbcapabilities import SmbSmbCapabilities, SmbSmbCapabilitiesTypedDict
from .smb_smbversions import SmbSmbVersions, SmbSmbVersionsTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SmbTypedDict(TypedDict):
    group_name: NotRequired[str]
    r"""Default group name"""
    has_ntlm: NotRequired[bool]
    r"""Server supports the NTLM authentication method"""
    native_os: NotRequired[str]
    r"""Server-identified operating system"""
    negotiation_log: NotRequired[SmbNegotiationLogTypedDict]
    ntlm: NotRequired[str]
    r"""Native LAN manager"""
    session_setup_log: NotRequired[SmbSessionSetupLogTypedDict]
    smb_capabilities: NotRequired[SmbSmbCapabilitiesTypedDict]
    smb_version: NotRequired[SmbSmbVersionsTypedDict]
    smbv1_support: NotRequired[bool]


class Smb(BaseModel):
    group_name: Optional[str] = None
    r"""Default group name"""

    has_ntlm: Optional[bool] = None
    r"""Server supports the NTLM authentication method"""

    native_os: Optional[str] = None
    r"""Server-identified operating system"""

    negotiation_log: Optional[SmbNegotiationLog] = None

    ntlm: Optional[str] = None
    r"""Native LAN manager"""

    session_setup_log: Optional[SmbSessionSetupLog] = None

    smb_capabilities: Optional[SmbSmbCapabilities] = None

    smb_version: Optional[SmbSmbVersions] = None

    smbv1_support: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .searchaggregateresponse import (
    SearchAggregateResponse,
    SearchAggregateResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeSearchAggregateResponseTypedDict(TypedDict):
    result: NotRequired[SearchAggregateResponseTypedDict]


class ResponseEnvelopeSearchAggregateResponse(BaseModel):
    result: Optional[SearchAggregateResponse] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collectioneventsresponse import (
    CollectionEventsResponse,
    CollectionEventsResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeCollectionEventsResponseTypedDict(TypedDict):
    result: NotRequired[CollectionEventsResponseTypedDict]


class ResponseEnvelopeCollectionEventsResponse(BaseModel):
    result: Optional[CollectionEventsResponse] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel, Nullable, UNSET_SENTINEL
from datetime import datetime
from enum import Enum
from pydantic import model_serializer
from typing_extensions import TypedDict


class CollectionStatus(str, Enum):
    UNSPECIFIED = "unspecified"
    POPULATING = "populating"
    ACTIVE = "active"
    PAUSED = "paused"
    ARCHIVED = "archived"


class StatusReason(str, Enum):
    UNSPECIFIED = "unspecified"
    NOT_ENOUGH_CREDITS = "not_enough_credits"
    NOT_ENTITLED = "not_entitled"
    TOO_MANY_ASSETS = "too_many_assets"
    MANUAL = "manual"
    QUERY_CHANGED = "query_changed"
    INITIAL = "initial"


class CollectionTypedDict(TypedDict):
    added_assets_24_hours: int
    create_time: datetime
    description: str
    id: str
    name: str
    query: str
    removed_assets_24_hours: int
    status: CollectionStatus
    status_reason: Nullable[StatusReason]
    total_assets: int


class Collection(BaseModel):
    added_assets_24_hours: int

    create_time: datetime

    description: str

    id: str

    name: str

    query: str

    removed_assets_24_hours: int

    status: CollectionStatus

    status_reason: Nullable[StatusReason]

    total_assets: int

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["status_reason"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ser2net_serialparameters import (
    Ser2NetSerialParameters,
    Ser2NetSerialParametersTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Ser2NetTypedDict(TypedDict):
    device: NotRequired[str]
    os: NotRequired[str]
    serial_parameters: NotRequired[Ser2NetSerialParametersTypedDict]
    software: NotRequired[str]
    software_version: NotRequired[str]


class Ser2Net(BaseModel):
    device: Optional[str] = None

    os: Optional[str] = None

    serial_parameters: Optional[Ser2NetSerialParameters] = None

    software: Optional[str] = None

    software_version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ZeromqGreetingTypedDict(TypedDict):
    as_server: NotRequired[bool]
    mechanism: NotRequired[str]
    signature: NotRequired[str]
    version_major: NotRequired[int]
    version_minor: NotRequired[int]


class ZeromqGreeting(BaseModel):
    as_server: Optional[bool] = None

    mechanism: Optional[str] = None

    signature: Optional[str] = None

    version_major: Optional[int] = None

    version_minor: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpVersionTypedDict(TypedDict):
    major: NotRequired[int]
    minor: NotRequired[int]
    raw: NotRequired[str]
    r"""Raw Version Response, Major version is stored in upper 2 bytes, minor in lower 2 bytes."""


class RdpVersion(BaseModel):
    major: Optional[int] = None

    minor: Optional[int] = None

    raw: Optional[str] = None
    r"""Raw Version Response, Major version is stored in upper 2 bytes, minor in lower 2 bytes."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responseenvelopehosttimeline import (
    ResponseEnvelopeHostTimeline,
    ResponseEnvelopeHostTimelineTypedDict,
)
from censys_platform.types import BaseModel
from censys_platform.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from datetime import datetime
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3GlobaldataAssetHostTimelineGlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class V3GlobaldataAssetHostTimelineGlobals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class V3GlobaldataAssetHostTimelineRequestTypedDict(TypedDict):
    host_id: str
    r"""The IP address of a host."""
    start_time: datetime
    r"""Start time of the host timeline. Equivalent to the To field in the event history UI. This must be the timestamp closest to the current time. For example, if you want events from January 1, 2025 to the start of January 2, 2025, input the January 2 timestamp here. Must be a valid RFC3339 string. Ensure that you suffix the date with T00:00:00Z or a specific time."""
    end_time: datetime
    r"""End time of the host timeline. Equivalent to the From field in the event history UI. This must be the timestamp furthest from the current time. For example, if you want events from January 1, 2025 to the start of January 2, 2025, input the January 1 timestamp here. Must be a valid RFC3339 string. Ensure that you suffix the date with T00:00:00Z or a specific time."""
    organization_id: NotRequired[str]
    r"""The ID of a Censys organization to associate the request with. If omitted, the request will be processed using the authenticated user's free wallet where applicable. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3GlobaldataAssetHostTimelineRequest(BaseModel):
    host_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The IP address of a host."""

    start_time: Annotated[
        datetime, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]
    r"""Start time of the host timeline. Equivalent to the To field in the event history UI. This must be the timestamp closest to the current time. For example, if you want events from January 1, 2025 to the start of January 2, 2025, input the January 2 timestamp here. Must be a valid RFC3339 string. Ensure that you suffix the date with T00:00:00Z or a specific time."""

    end_time: Annotated[
        datetime, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]
    r"""End time of the host timeline. Equivalent to the From field in the event history UI. This must be the timestamp furthest from the current time. For example, if you want events from January 1, 2025 to the start of January 2, 2025, input the January 1 timestamp here. Must be a valid RFC3339 string. Ensure that you suffix the date with T00:00:00Z or a specific time."""

    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The ID of a Censys organization to associate the request with. If omitted, the request will be processed using the authenticated user's free wallet where applicable. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3GlobaldataAssetHostTimelineResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResponseEnvelopeHostTimelineTypedDict


class V3GlobaldataAssetHostTimelineResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResponseEnvelopeHostTimeline



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchErrorMessageTypedDict(TypedDict):
    header: NotRequired[str]
    reason: NotRequired[str]
    type: NotRequired[str]


class ElasticSearchErrorMessage(BaseModel):
    header: Optional[str] = None

    reason: Optional[str] = None

    type: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OracleDescriptorTypedDict(TypedDict):
    key: NotRequired[str]
    r"""The dot-delimited path to the parsed value from the error received when the initial handshake is refused."""
    value: NotRequired[str]
    r"""The parsed value from the error received when the initial handshake is refused."""


class OracleDescriptor(BaseModel):
    key: Optional[str] = None
    r"""The dot-delimited path to the parsed value from the error received when the initial handshake is refused."""

    value: Optional[str] = None
    r"""The parsed value from the error received when the initial handshake is refused."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .trackedscan import TrackedScan, TrackedScanTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeTrackedScanTypedDict(TypedDict):
    result: NotRequired[TrackedScanTypedDict]


class ResponseEnvelopeTrackedScan(BaseModel):
    result: Optional[TrackedScan] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ScpiTypedDict(TypedDict):
    firmware: NotRequired[str]
    manufacturer: NotRequired[str]
    model: NotRequired[str]
    serial: NotRequired[str]


class Scpi(BaseModel):
    firmware: Optional[str] = None

    manufacturer: Optional[str] = None

    model: Optional[str] = None

    serial: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IbmnjeTypedDict(TypedDict):
    ohost: NotRequired[str]
    oip: NotRequired[str]
    reason: NotRequired[int]
    rhost: NotRequired[str]
    rip: NotRequired[str]
    type: NotRequired[str]


class Ibmnje(BaseModel):
    ohost: Optional[str] = None

    oip: Optional[str] = None

    reason: Optional[int] = None

    rhost: Optional[str] = None

    rip: Optional[str] = None

    type: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .monerop2p_pingresponse import (
    MoneroP2PPingResponse,
    MoneroP2PPingResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MoneroP2PTypedDict(TypedDict):
    ping_response: NotRequired[MoneroP2PPingResponseTypedDict]


class MoneroP2P(BaseModel):
    ping_response: Optional[MoneroP2PPingResponse] = None
